@@ -34,6 +34,8 @@ enum { WM_NAME,
 	TOTAL_ATOMS
 };
 
+#define XKL_NUMBER_OF_REGISTRY_DOCS 2
+
 struct _XklEnginePrivate {
 
 	gboolean group_per_toplevel_window;
@@ -97,7 +99,8 @@ struct _XklEnginePrivate {
 	 * xkb: loads xml from XKB_BASE+"/rules/"+ruleset+".xml"
 	 * xmodmap: loads xml from XMODMAP_BASE+"/"+ruleset+".xml"
 	 */
-	 gboolean(*load_config_registry) (XklConfigRegistry * config);
+	 gboolean(*load_config_registry) (XklConfigRegistry * config,
+					  gboolean if_extras_needed);
 
 	/*
 	 * Write the configuration into the file (binary/textual)
@@ -245,9 +248,8 @@ extern XklEngine *xkl_get_the_engine(void);
 struct _XklConfigRegistryPrivate {
 	XklEngine *engine;
 
-	xmlDocPtr doc;
-
-	xmlXPathContextPtr xpath_context;
+	xmlDocPtr docs[XKL_NUMBER_OF_REGISTRY_DOCS];
+	xmlXPathContextPtr xpath_contexts[XKL_NUMBER_OF_REGISTRY_DOCS];
 };
 
 extern void xkl_engine_ensure_vtable_inited(XklEngine * engine);
@@ -261,7 +263,7 @@ extern void xkl_engine_process_property_evt(XklEngine * engine,
 extern void xkl_engine_process_create_window_evt(XklEngine * engine,
 						 XCreateWindowEvent * cev);
 
-extern void xkl_process_error(Display * dpy, XErrorEvent * evt);
+extern int xkl_process_error(Display * dpy, XErrorEvent * evt);
 
 extern void xkl_engine_process_state_modification(XklEngine * engine,
 						  XklEngineStateChange
@@ -388,18 +390,18 @@ extern void xkl_engine_one_switch_to_secondary_group_performed(XklEngine *
 
 extern gboolean xkl_config_registry_load_from_file(XklConfigRegistry *
 						   config,
-						   const gchar *
-						   file_name);
+						   const gchar * file_name,
+						   gint docidx);
 
 extern void xkl_config_registry_free(XklConfigRegistry * config);
 
 extern gchar *xkl_locale_from_utf8(XklConfigRegistry * config,
 				   const gchar * utf8string);
 
-extern gboolean xkl_config_registry_load_helper(XklConfigRegistry * config,
-						const char
+extern gboolean xkl_config_registry_load_helper(XklConfigRegistry * config, const char
 						default_ruleset[],
-						const char base_dir[]);
+						const char base_dir[],
+						gboolean if_extras_needed);
 
 #define XKLAVIER_STATE_PROP_LENGTH 2
 
@@ -414,7 +416,7 @@ extern gboolean xkl_config_registry_load_helper(XklConfigRegistry * config,
 #define xkl_engine_vcall(engine,func)  (*(engine)->priv->func)
 
 #define xkl_config_registry_is_initialized(config) \
-  ( xkl_config_registry_priv(config,xpath_context) != NULL )
+  ( xkl_config_registry_priv(config,xpath_contexts[0]) != NULL )
 
 #define xkl_config_registry_priv(config,member)  (config)->priv->member
 #define xkl_config_registry_get_engine(config) ((config)->priv->engine)
@@ -434,6 +436,9 @@ extern gboolean xkl_config_registry_load_helper(XklConfigRegistry * config,
 #define XML_TAG_ISO639ID "iso639Id"
 
 extern void
+
+
+
 xkl_config_registry_foreach_in_xpath_with_param(XklConfigRegistry * config,
 						const gchar * format,
 						const gchar * value,
@@ -448,7 +453,7 @@ extern void xkl_config_registry_foreach_in_xpath(XklConfigRegistry *
 						 func, gpointer data);
 
 extern gboolean xkl_read_config_item(XklConfigRegistry * config,
-				     xmlNodePtr iptr,
+				     gint doc_index, xmlNodePtr iptr,
 				     XklConfigItem * item);
 
 extern gint xkl_debug_level;
